@@ -1004,11 +1004,21 @@ inline int gpuDeviceInit(int devID)
     cudaDeviceProp deviceProp;
     checkCudaErrors(cudaGetDeviceProperties(&deviceProp, devID));
 
+#if CUDA_VERSION < 13000
     if (deviceProp.computeMode == cudaComputeModeProhibited)
     {
         fprintf(stderr, "Error: device is running in <Compute Mode Prohibited>, no threads can use ::cudaSetDevice().\n");
         return -1;
     }
+#else
+    int computeMode;
+    cudaDeviceGetAttribute(&computeMode, cudaDevAttrComputeMode, devID);
+    if (computeMode == cudaComputeModeProhibited)
+    {
+        fprintf(stderr, "Error: device is running in <Compute Mode Prohibited>, no threads can use ::cudaSetDevice().\n");
+        return -1;
+    }
+#endif
 
     if (deviceProp.major < 1)
     {
@@ -1048,7 +1058,13 @@ inline int gpuGetMaxGflopsDeviceId()
         cudaGetDeviceProperties(&deviceProp, current_device);
 
         // If this GPU is not running on Compute Mode prohibited, then we can add it to the list
+#if CUDA_VERSION < 13000
         if (deviceProp.computeMode != cudaComputeModeProhibited)
+#else
+        int computeMode;
+        cudaDeviceGetAttribute(&computeMode, cudaDevAttrComputeMode, current_device);
+        if (computeMode != cudaComputeModeProhibited)
+#endif
         {
             if (deviceProp.major > 0 && deviceProp.major < 9999)
             {
@@ -1077,6 +1093,7 @@ inline int gpuGetMaxGflopsDeviceId()
         cudaGetDeviceProperties(&deviceProp, current_device);
 
         // If this GPU is not running on Compute Mode prohibited, then we can add it to the list
+#if CUDA_VERSION < 13000
         if (deviceProp.computeMode != cudaComputeModeProhibited)
         {
             if (deviceProp.major == 9999 && deviceProp.minor == 9999)
@@ -1089,6 +1106,24 @@ inline int gpuGetMaxGflopsDeviceId()
             }
 
             unsigned long long compute_perf  = (unsigned long long) deviceProp.multiProcessorCount * sm_per_multiproc * deviceProp.clockRate;
+#else
+        int computeMode;
+        cudaDeviceGetAttribute(&computeMode, cudaDevAttrComputeMode, current_device);
+        if (computeMode != cudaComputeModeProhibited)
+        {
+            if (deviceProp.major == 9999 && deviceProp.minor == 9999)
+            {
+                sm_per_multiproc = 1;
+            }
+            else
+            {
+                sm_per_multiproc = _ConvertSMVer2Cores(deviceProp.major, deviceProp.minor);
+            }
+
+            int clockRate;
+            cudaDeviceGetAttribute(&clockRate, cudaDevAttrClockRate, current_device);
+            unsigned long long compute_perf  = (unsigned long long) deviceProp.multiProcessorCount * sm_per_multiproc * clockRate;
+#endif
 
             if (compute_perf  > max_compute_perf)
             {
